@@ -123,6 +123,16 @@ test 'simple user tests' => sub {
     cmp_ok( $schema->resultset('Role')->count,
         '==', $role_count, "$role_count roles" );
 
+    $data = {
+        username => 'user@example.com',
+        email    => 'user@example.com',
+    };
+
+    lives_ok( sub { $result = $rset_user->create($data) },
+        "create user with no password" );
+
+    ok(!$result->check_password(''), "cannot login with empty password");
+    ok(!$result->check_password(undef), "cannot login with undef password");
     # cleanup
     $self->clear_users;
 };
